use strict;
use warnings;
package Net::Disqus::Interfaces;
BEGIN {
  $Net::Disqus::Interfaces::VERSION = '1.19';
}

# this got turned into a module since bundling a json file is often
# a pain in the you-know-whatsit - plus I forgot to add it to the Dist::Zilla
# distribution last time, so as a module at least it get picked up all the time 
# regardless. 
sub INTERFACES { return {'imports' => {'details' => {'formats' => ['json','jsonp'],'required' => ['group'],'method' => 'GET'},'list' => {'formats' => ['json','jsonp'],'required' => ['forum'],'method' => 'GET'}},'applications' => {'listUsage' => {'formats' => ['json','jsonp'],'required' => [],'method' => 'GET'}},'categories' => {'listPosts' => {'formats' => ['json','jsonp','rss'],'required' => ['category'],'method' => 'GET'},'details' => {'formats' => ['json','jsonp'],'required' => ['category'],'method' => 'GET'},'list' => {'formats' => ['json','jsonp'],'required' => [],'method' => 'GET'},'listThreads' => {'formats' => ['json','jsonp','rss'],'required' => ['category'],'method' => 'GET'}},'users' => {'follow' => {'formats' => ['json','jsonp'],'required' => [],'method' => 'POST'},'listFollowers' => {'formats' => ['json','jsonp'],'required' => [],'method' => 'GET'},'listMostActiveForums' => {'formats' => ['json','jsonp'],'required' => [],'method' => 'GET'},'listForums' => {'formats' => ['json','jsonp'],'required' => [],'method' => 'GET'},'listActivity' => {'formats' => ['json','jsonp'],'required' => [],'method' => 'GET'},'details' => {'formats' => ['json','jsonp'],'required' => [],'method' => 'GET'},'unfollow' => {'formats' => ['json','jsonp'],'required' => [],'method' => 'POST'},'listFollowing' => {'formats' => ['json','jsonp'],'required' => [],'method' => 'GET'},'listActiveForums' => {'formats' => ['json','jsonp'],'required' => [],'method' => 'GET'}},'threads' => {'create' => {'formats' => ['json','jsonp'],'required' => ['forum','title'],'method' => 'POST'},'remove' => {'formats' => ['json','jsonp'],'required' => ['thread'],'method' => 'POST'},'listSimilar' => {'formats' => ['json','jsonp','rss'],'required' => ['thread'],'method' => 'GET'},'listByDate' => {'formats' => ['json','jsonp','rss'],'required' => [],'method' => 'GET'},'vote' => {'formats' => ['json','jsonp'],'required' => ['thread','vote'],'method' => 'POST'},'restore' => {'formats' => ['json','jsonp'],'required' => ['thread'],'method' => 'POST'},'details' => {'formats' => ['json','jsonp'],'required' => ['thread'],'method' => 'GET'},'listHot' => {'formats' => ['json','jsonp','rss'],'required' => [],'method' => 'GET'},'open' => {'formats' => ['json','jsonp'],'required' => ['thread'],'method' => 'POST'},'listMostLiked' => {'formats' => ['json','jsonp','rss'],'required' => [],'method' => 'GET'},'close' => {'formats' => ['json','jsonp'],'required' => ['thread'],'method' => 'POST'},'listPosts' => {'formats' => ['json','jsonp','rss'],'required' => ['thread'],'method' => 'GET'},'update' => {'formats' => ['json','jsonp'],'required' => ['thread'],'method' => 'POST'},'list' => {'formats' => ['json','jsonp','rss'],'required' => [],'method' => 'GET'}},'whitelists' => {'remove' => {'formats' => ['json','jsonp'],'required' => ['forum'],'method' => 'POST'},'add' => {'formats' => ['json','jsonp'],'required' => ['forum'],'method' => 'POST'},'list' => {'formats' => ['json','jsonp'],'required' => ['forum'],'method' => 'GET'}},'exports' => {'exportForum' => {'formats' => ['json','jsonp'],'required' => ['forum'],'method' => 'POST'}},'reactions' => {'details' => {'formats' => ['json','jsonp'],'required' => ['reaction'],'method' => 'GET'},'list' => {'formats' => ['json','jsonp'],'required' => ['forum'],'method' => 'POST'}},'blacklists' => {'remove' => {'formats' => ['json','jsonp'],'required' => ['forum'],'method' => 'POST'},'add' => {'formats' => ['json','jsonp'],'required' => ['forum'],'method' => 'POST'},'list' => {'formats' => ['json','jsonp'],'required' => ['forum'],'method' => 'GET'}},'trends' => {'listThreads' => {'formats' => ['json','jsonp','rss'],'required' => [],'method' => 'GET'}},'forums' => {'listUsers' => {'formats' => ['json','jsonp'],'required' => ['forum'],'method' => 'GET'},'listPosts' => {'formats' => ['json','jsonp','rss'],'required' => ['forum'],'method' => 'GET'},'listMostLikedUsers' => {'formats' => ['json','jsonp'],'required' => ['forum'],'method' => 'GET'},'details' => {'formats' => ['json','jsonp'],'required' => ['forum'],'method' => 'GET'},'listCategories' => {'formats' => ['json','jsonp'],'required' => ['forum'],'method' => 'GET'},'listThreads' => {'formats' => ['json','jsonp','rss'],'required' => ['forum'],'method' => 'GET'}},'reports' => {'domains' => {'formats' => ['json','jsonp'],'required' => [],'method' => 'GET'},'ips' => {'formats' => ['json','jsonp'],'required' => [],'method' => 'GET'},'users' => {'formats' => ['json','jsonp'],'required' => [],'method' => 'GET'},'threads' => {'formats' => ['json','jsonp'],'required' => [],'method' => 'GET'}},'posts' => {'create' => {'formats' => ['json','jsonp'],'required' => ['message'],'method' => 'POST'},'remove' => {'formats' => ['json','jsonp'],'required' => ['post'],'method' => 'POST'},'search' => {'formats' => ['json','jsonp','rss'],'required' => ['query'],'method' => 'GET'},'vote' => {'formats' => ['json','jsonp'],'required' => ['vote','post'],'method' => 'POST'},'restore' => {'formats' => ['json','jsonp'],'required' => ['post'],'method' => 'POST'},'details' => {'formats' => ['json','jsonp'],'required' => ['post'],'method' => 'GET'},'approve' => {'formats' => ['json','jsonp'],'required' => ['post'],'method' => 'POST'},'spam' => {'formats' => ['json','jsonp'],'required' => ['post'],'method' => 'POST'},'report' => {'formats' => ['json','jsonp'],'required' => ['post'],'method' => 'POST'},'listPopular' => {'formats' => ['json','jsonp','rss'],'required' => [],'method' => 'GET'},'list' => {'formats' => ['json','jsonp','rss'],'required' => [],'method' => 'GET'}}}; }

1;
